#!/bin/sh -f
#*******************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: fims.sh,v 2.43 2004/06/17 23:04:31 vltsccm Exp $"
#
# who       when      what
# --------  --------  ----------------------------------------------
#  hummel    09/07/98   created
#  wgaessle  18/07/98   deleted eso examples, changed FORS_OSS_ROOT to
#                       FIMSROOT same for INS_ROOT. Set path for file
#			loaded with skycat to $INS_ROOT/SYSTEM/COMMON/
#			PREPARATION
#  hummel    04/01/99   Edit this file (lines 100-110)
#  hummel    07/01/99   for fims 1.2.6                     
#  hummel    12/01/99   for fims 1.2.7                     
#  hummel    27/01/99   for fims 1.3.0                     
#  aaguayo   14/03/01   for fims 2.28 (use of SKYCAT_VER variable)
#  mkiekebu  31/03/01   for fims 2.29
#
#  smarteau  09/07/04   Modified for installation of P74 package
#    
#************************************************************************
#   NAME
#       fims.sh - startup shell script for FIMS
#
#   SYNOPSIS
#       fims.sh 
#       fims.sh 1
#       fims.sh 2 "<skycat command line options>"
#
#   DESCRIPTION
#       This shell script sets all relevant UNIX environment variables
#       to plugin the FIMS module to the ESO SkyCat Tool
#       This scripts has three parts  
#       1) set the site-dependent environment variables  
#       2) check if everything is found                  
#       3) start skycat with some command line options  
#       For FIMS installation edit 1) according to your local site preferences
#
#   FILES
#       fims.sh
#
#   ENVIRONMENT
#       HP-UX-10.20, OSF, SunOs, Linux
#       SkyCat Tool V2.2
#
#   RETURN VALUES
#       none
#
#   CAUTIONS
#       skycat command line options have to be included in double quotes
#
#   EXAMPLES
#        usage: fims.sh [0-1] <"SkyCat command line parameter"> <DEBUG>"
#        examples : 
#
#       fims.sh                           (equivalent to fims.sh 2)
#       fims.sh 0                         (both instruments)
#       fims.sh 1                         (only for FORS1)
#       fims.sh 2                         (only for FORS2)
#       fims.sh 0 ""                      (no skycat option, as example before)
#       fims.sh 0 "-float_panel 1 -rtd 1" (with skycat options)
#       fims.sh 0 "-withscrollbars"       (no skycat option)
#       fims.sh 1 "-file $HOME/FITS/ngc0815.fits -catalog $HOME/cat/gsc0815.ptl"
#       fims.sh 1 "-rtd 1 -with_grid 1 -scrollbars 1 -float_panel 1"
#       fims.sh 0 "" DEBUG                (shows detailled environments, 
#                                         use this option to verify installation)
#       fims.sh 2 "-rtd 0" DEBUG          (FORS2 only, with skycat option, and 
#
#   SEE ALSO
#       sct_ec.tcl
#       FIMS Installation Guide 
#
#   BUGS
#
#------------------------------------------------------------------------
#


# ------------- Part 1 set environments ------------------

if [ -z "$SKYCAT_VER" ]; then
#	SKYCAT_VER=2.7.3; export SKYCAT_VER
	SKYCAT_VER=3.0; export SKYCAT_VER
fi

S_V=$SKYCAT_VER

# default instrument option  
FORS_INST=${1:-2}; export FORS_INST

# default command line options for skycat
CLS="-with_grid 1 -scrollbars 1 -rtd 0"

# command line options for skycat 
CLO=${2:-$CLS}

# private="-file /usr3/hummel/FITS/ngc330-1/COM26_NGC330_0.be.2.fits"
# private="-file /home/hummel/FITS/GaTi_22/V500Aql.fits" 
# private="-file /home/hummel/FITS/COM26_NGC330_0.be.2.fits" 
# private="-float_panel 1 -catalog /home/hummel/FITS/COMM2/../FITS/ngc330-1/total.ptl -file /home/hummel/FITS/COMM2/../FITS/ngc330-1/COM26_NGC330_0.be.2.fits"

# default debug option  
DB=${3:-false}
if [ $DB != false ]; then DB=true; fi


case $FORS_INST in
       0 )
       if $DB; then echo " FORS_INS            = FORS1+FORS2"; fi;;
       1 )
       if $DB; then echo " FORS_INS            = FORS$FORS_INST"; fi;;
       2 )
       if $DB; then echo " FORS_INS            = FORS$FORS_INST"; fi;;
       * )
       echo "Exit : there is no FORS$1 available; try 0 or 1 or 2"
       exit;;
esac
echo

      # any other workstation outside the VLT - FORS environment 
       
      FIMSROOT=${FIMSROOT:-$HOME/fims};  export FIMSROOT;  # where fims is installed
      ISF_DIR=$FIMSROOT/lib/fors;       export ISF_DIR;  # FORS1.isf from FIMS package

      INS_ROOT=$HOME;            export INS_ROOT; # user home directory 

     INS_USER=.fims;                   export INS_USER; # fims output dir 
     PREP_DIR=$INS_ROOT/$INS_USER/PREP;export PREP_DIR; # where is the fits file 
      LOG_DIR=$INS_ROOT/$INS_USER/LOG; export LOG_DIR;  # keep this 
      SET_DIR=$INS_ROOT/$INS_USER/SET; export SET_DIR;  # keep this 

# copy the MXU standard masks to the SET directory 
# echo "copy MXU technical masks to $SET_DIR"

      cp $FIMSROOT/src/mxu2.009.standard.fad $SET_DIR/.
      chmod +w $SET_DIR/mxu2.009.standard.fad
      cp $FIMSROOT/src/mxu2.010.standard.fad $SET_DIR/.
      chmod +w $SET_DIR/mxu2.010.standard.fad
      cp $FIMSROOT/src/mxu2.011.standard.fad $SET_DIR/.
      chmod +w $SET_DIR/mxu2.011.standard.fad

# The FORS1.isf file can be either from the on-line database (Paranal)
# from the FIMS package (must be updated each observing period)
# or from the P2PP FORS1-Instrument-Package (also updated)


# -------------------- PART 2 -- check settings -----------------


if [ -d $FIMSROOT ] 
   then 
   if $DB; then echo " FIMSROOT            = $FIMSROOT"; fi
   else echo "ERROR: >$FIMSROOT< does not exist"
        echo ">>>>>hint:"
        echo "setenv FIMSROOT <..>/fims (your FIMS installation directory)"
        echo "FIMSROOT=<..>/fims; export FIMSROOT (for bash)"
        echo "setenv FIMSROOT ${PWD}/.."
        exit
fi

if [ -d $INS_ROOT ] 
   then 
   if $DB; then echo " INS_ROOT            = $INS_ROOT"; fi 
   else echo "ERROR: $INS_ROOT does not exist"
        mkdir $INS_ROOT
        echo "created ----- $INS_ROOT"
fi 

if [ -d $INS_ROOT/$INS_USER ]
   then 
   if $DB; then echo " INS_ROOT/INS_USER   = $INS_ROOT/$INS_USER"; fi
   else echo "ERROR: >$INS_ROOT/$INS_USER< does not exist"
        mkdir $INS_ROOT/$INS_USER
        echo "created ----- $INS_ROOT/$INS_USER"
fi

# where to write the target setup files 
# -------------------------------------
if [ -d $SET_DIR ]
   then 
   if $DB; then echo " SET_DIR             = $SET_DIR"; fi
   else echo "ERROR: >$SET_DIR< does not exist"
        mkdir $SET_DIR
        echo "created ----- $SET_DIR"
fi

# where to write the FIMS log files  
# -------------------------------------
if [ -d $LOG_DIR ]
   then 
   if $DB; then echo " LOG_DIR             = $LOG_DIR"; fi 
   else echo "ERROR: >$LOG_DIR< does not exist"
        mkdir $LOG_DIR
        echo "created ----- $LOG_DIR"
fi

# from where to load the fits files  
# -------------------------------------
if [ -d $PREP_DIR ]
   then 
   if $DB; then echo " PREP_DIR            = $PREP_DIR"; fi 
   else echo "ERROR: >$PREP_DIR< does not exist"
        mkdir $PREP_DIR
        echo "created ----- $PREP_DIR"
fi



if [ -d $ISF_DIR ]
   then 
   if $DB; then echo " ISF_DIR             = $ISF_DIR"; fi 
   else echo "ERROR: >$ISF_DIR< does not exist"
        ISF_DIR=$FIMSROOT/lib/fors
        if [ -d $ISF_DIR ]; then 
             echo "found: >$ISF_DIR< (FIMS internal)"
        else echo "FIMS Installation Error"
             echo ">>>>>hint:"
             echo "make"
             exit
fi
fi


if [ -f $ISF_DIR/FORS$FORS_INST.isf ]
   then 
   if $DB; then echo " FORS$FORS_INST.isf from       $ISF_DIR/FORS$FORS_INST.isf"; fi 
   else
   if [ $FORS_INST -eq "0" ] 
      then 
      if [ -f $ISF_DIR/FORS1.isf ]
         then 
         if $DB; then echo " FORS1.isf from       $ISF_DIR/FORS1.isf"; fi
         else 
         echo " $ISF_DIR/FORS1.isf does not exist"
         echo ">>>>>hint:"
         echo "fims.sh  0 \"-rtd 0\" DEBUG"
         echo
         exit 1
         fi
      if [ -f $ISF_DIR/FORS2.isf ]
         then 
         if $DB; then echo " FORS2.isf from       $ISF_DIR/FORS2.isf"; fi
         else 
         echo " $ISF_DIR/FORS2.isf does not exist"
         echo "to debug try:"
         echo "fims 0 \"-rtd 0\" DEBUG"
         echo
         exit 1
         fi
      fi
fi


#-------------- P L U G I N S -------------------------------
        ESO_PLUG=$FIMSROOT/lib/libesoPlugins.tcl;      

       FIMS_PLUG=$FIMSROOT/lib/libfimsPlugins.tcl;    
       FRTD_PLUG=$FIMSROOT/lib/libfrtdPlugins.tcl;

# 09jul2004: added path to Finding Chart plug-in
         FC_PLUG=$FIMSROOT/../lib/libfcPlugins.tcl;

SKYSEARCH_PLUGIN=$FIMS_PLUG/SkySearch_plugin.tcl;       export SKYSEARCH_PLUGIN
   RTD_PLUGIN=$FRTD_PLUG/Rtd_plugin.tcl;             export RTD_PLUGIN
   SKYCAT_PLUG01=$FIMS_PLUG/SkyCat_plugin.tcl;
   SKYCAT_PLUG02=$ESO_PLUG/PE_SkyCat_plugin.tcl;

# 09jul2004: Finding Chart plug-in
   SKYCAT_PLUG03=$FC_PLUG/FindingChart_plugin.tcl;


if $DB
then
echo
echo " ESO_PLUG            = $ESO_PLUG"
echo
#echo " RTD_PLUGIN          = $RTD_PLUGIN"
echo " SKYSEARCH_PLUGIN    = $SKYSEARCH_PLUGIN"
echo " SKYCAT_PLUG01       = $SKYCAT_PLUG01"
echo " SKYCAT_PLUG02       = $SKYCAT_PLUG02"
# 09jul2004: Finding Chart plug-in
echo " SKYCAT_PLUG03       = $SKYCAT_PLUG03"
echo
echo " test if file exists"
echo 
if [ -f $SKYSEARCH_PLUGIN ]; then echo " found: $SKYSEARCH_PLUGIN"; else echo " where? $SKYSEARCH_PLUGIN"; fi
#if [ -f $RTD_PLUGIN ];       then echo " found: $RTD_PLUGIN";       else echo " where? $RTD_PLUGIN"; fi
if [ -f $SKYCAT_PLUG01 ];    then echo " found: $SKYCAT_PLUG01";    else echo " where? $SKYCAT_PLUG01"; fi
if [ -f $SKYCAT_PLUG02 ];    then echo " found: $SKYCAT_PLUG02";    else echo " where? $SKYCAT_PLUG02"; fi
if [ -f $SKYCAT_PLUG03 ];    then echo " found: $SKYCAT_PLUG03";    else echo " where? $SKYCAT_PLUG03"; fi
echo
fi

# join all plugins to one single keyword
SKYCAT_PLUGIN=$SKYCAT_PLUG03:$SKYCAT_PLUG02:$SKYCAT_PLUG01; export SKYCAT_PLUGIN

if $DB; then echo " SKYCAT_PLUGIN       = >$SKYCAT_PLUGIN<"; fi


# ----------------------------
# print current version number 
# ----------------------------
echo
echo
echo
echo "  W E L C O M E     T O     F I M S"
echo " -----------------------------------"
echo 
  echo " +----------------+                +------------------+"
awk ' $4 ~ /fims.sh,v/ {
printf(" | FIMS  %8s |----plugin----> | SkyCatTool ", $5) }' $FIMSROOT/bin/fims.sh
echo $S_V" |"
  echo " +----------------+                +------------------+"



echo
echo   " +------------------------------------------+"
awk ' $4 ~ /fims.sh,v/ { 
printf(" | last checkin : %s GD %s UT", $6, $7) }' $FIMSROOT/bin/fims.sh
echo " | INPUT : "$PREP_DIR
echo   " | now is       : "`date -u +%Y/%m/%d`" GD "`date -u +%H:%M:%S`" UT | OUTPUT: "$SET_DIR
echo   " | FIMS requires: SkyCat "$S_V"              | LOGS  :" $LOG_DIR
echo   " +------------------------------------------+"
echo 


  

# ------------------ PART 3 --- start skycat ------------------
echo

echo "skycat $CLO $private ..."

# call skycat

skycat  $CLO $private 

#
# ___oOo___
